@@ -8,10 +8,11 @@ test -n "${BASHRC_FILE}" || { error.bash BASHRC_FILE 'not defined'; return 1; }
 function home_bashrc() {
   local user home file bashrc_path
   if bashrc_path="$( command -v "${BASHRC_FILE}" 2>&1 )"; then
-    echo '# shellcheck disable=SC1090' | sudo -u "${1}" tee "${2}" >/dev/null
+#    echo '# shellcheck disable=SC1090' | sudo -u "${1}" tee "${2}" >/dev/null
     # shellcheck disable=SC2016
-    echo 'test -n "${PS1}" || return' | sudo -u "${1}" tee -a "${2}" >/dev/null
-    if sudo -u "${1}" tee -a "${2}" >/dev/null <<EOT; then
+#    echo 'test -n "${PS1}" || return' | sudo -u "${1}" tee -a "${2}" >/dev/null
+#    if sudo -u "${1}" tee -a "${2}" >/dev/null <<EOT; then
+    if sudo -u "${1}" tee "${2}" >/dev/null <<EOT; then
 if test -f  "${bashrc_path}"; then
   source "${bashrc_path}"
 else
@@ -119,9 +120,9 @@ function home_links() {
       touch .gitconfig
       for file in .ssh/config .ssh/gitcredentials .gitconfig \
                   $( find .ssh -type f -exec grep -l "END OPENSSH PRIVATE KEY" "{}" \; ) .gitconfig; do
-        sudo -u "${user}" cp -rf "${USERHOME}/${file}" "${home}/${file}"
-        sudo -u "${user}" chown -R go-rw "${home}/.ssh"
-        sudo -u "${user}" chmod -R "${user}":"$( id -g "${user}" )" "${home}/.ssh"
+        sudo -u "${user}" cp -rf "${USERHOME}/${file}" "${home}/${file}" > /dev/null 2>&1
+        sudo -u "${user}" chmod -R go-rw "${home}/.ssh"
+        sudo -u "${user}" chown -R "${user}":"$( id -g "${user}" )" "${home}/.ssh"
       done
     fi
     done
